(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     26857,        654]*)
(*NotebookOutlinePosition[     27513,        677]*)
(*  CellTagsIndexPosition[     27469,        673]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Maskit Algorithms", "Title"],

Cell["Dan Goodman 2006", "Subtitle"],

Cell["\<\
This notebook contains the algorithms described in the chapter on algorithms \
from my thesis.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Code", "Section"],

Cell[CellGroupData[{

Cell["Useful tidbits", "Subsection"],

Cell["\<\
This replacement rule replaces every instance of a complex number with the \
pair {Re[z],Im[z]}, it's useful for converting lists of complex numbers into \
something which can be plotted. You use it by typing list/.CpxToPair.\
\>", "Text"],

Cell[BoxData[
    \(\(CpxToPair = z_Complex \[Rule] {Re[z], Im[z]};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Farey fractions", "Subsection"],

Cell["\<\
Various useful functions for manipulating Farey sequences. The \[CirclePlus] \
operator is the Farey sum of two fractions. FareyList quickly gives the \
sequence of fractions p/q with q<=qmax and 0<=p/q<=1. If you already have a \
sequence of fractions between r1 and r2 say, and you want to fill in extra \
fractions up to a new maximum denominator you can use the \
CompleteFareySubdivision function. This is useful if you have plotted a part \
of the boundary and want to do a more detailed zoom into a subset. It is used \
by the GetSpecifier function below. It works by repeatedly adjoining the \
farey sum of adjacent fractions to the list (and removing those whose \
denominator is bigger than qmax) until you've got them all. It's very slow, \
but as long as your list of fractions is reasonably small it's quick enough, \
and for very large denominators but small lists it is quicker to use this \
than to find the complete FareyList and then get the subset of fractions you \
want.\
\>", "Text"],

Cell[BoxData[{
    \(\(f1_\[CirclePlus]f2_ := \((Numerator[f1] + 
              Numerator[f2])\)/\((Denominator[f1] + 
              Denominator[f2])\);\)\), "\[IndentingNewLine]", 
    \(\(FareyList[qmax_] := 
        Union[Flatten[
            Table[p/q, {q, 1, qmax}, {p, 0, 
                q}]]];\)\), "\[IndentingNewLine]", 
    \(\(FareySubdivide[list_List] := 
        Union[list, 
          Function[z, 
              z\[LeftDoubleBracket]1\[RightDoubleBracket]\[CirclePlus]z\
\[LeftDoubleBracket]2\[RightDoubleBracket]] /@ 
            Partition[list, 2, 1]];\)\), "\[IndentingNewLine]", 
    \(\(FareySubdivide[list_List, qmax_] := 
        Select[FareySubdivide[list], 
          Function[z, 
            Denominator[z] \[LessEqual] qmax]];\)\), "\[IndentingNewLine]", 
    \(\(CompleteFareySubdivision[list_List, qmax_] := 
        list //. x_List \[Rule] FareySubdivide[x, qmax];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Trace functions", "Subsection"],

Cell[TextData[{
  "This gives the recursive definition of the trace function as described in \
my thesis. The RecursiveOnlyTrF function is used when you want to ensure that \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " won't convert it into a polynomial, for example to ensure that it \
computes quickly and accurately in FindRoot. It does this by only evaluating \
when the parameter mu is a complex number (rather than a symbolic \
expression). This is the meaning of mu_Complex in the function definition."
}], "Text"],

Cell[BoxData[{
    \(\(TrF[uv_, uv_, rs_, x_, y_, z_] := x;\)\), "\[IndentingNewLine]", 
    \(\(TrF[uv_, pq_, uv_, x_, y_, z_] := y;\)\), "\[IndentingNewLine]", 
    \(TrF[uv_, pq_, rs_, x_, y_, z_] := 
      TrF[uv, pq, pq\[CirclePlus]rs, x, x\ y\  - z, y] /; 
        pq\[CirclePlus]rs > uv\), "\[IndentingNewLine]", 
    \(TrF[uv_, pq_, rs_, x_, y_, z_] := 
      TrF[uv, pq\[CirclePlus]rs, rs, x\ y\  - z, y, x] /; 
        pq\[CirclePlus]rs <= uv\), "\[IndentingNewLine]", 
    \(\(TrF[uv_, mu_] := 
        TrF[uv, 0/1, 1/1, \(-I\)\ mu, \(-I\)\ mu + 2  I, 
          2];\)\), "\[IndentingNewLine]", 
    \(\(RecursiveOnlyTrF[uv_, mu_Complex] := TrF[uv, mu];\)\)}], "Input"],

Cell["\<\
This gives the trace function and its derivative (the coefficients of the \
linearisation of the trace function at the cusp). DTrF gives just the \
derivative of the trace function. It's a little silly to compute the trace \
and trace derivative only in order to compute the derivative, but I don't see \
any clever way of avoiding this in practice in the boundary computation \
routines later. As before, the RecursiveOnly version won't evaluate with \
symbolic expressions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(LinearCoeffTrF[uv_, uv_, rs_, x_, y_, z_, dx_, dy_, dz_] := {x, 
          dx};\)\), "\[IndentingNewLine]", 
    \(\(LinearCoeffTrF[uv_, pq_, uv_, x_, y_, z_, dx_, dy_, dz_] := {y, 
          dy};\)\), "\[IndentingNewLine]", 
    \(LinearCoeffTrF[uv_, pq_, rs_, x_, y_, z_, dx_, dy_, dz_] := 
      LinearCoeffTrF[uv, pq, pq\[CirclePlus]rs, x, x\ y\  - z, y, dx, 
          x\ dy + dx\ y - dz, dy] /; 
        pq\[CirclePlus]rs > uv\), "\[IndentingNewLine]", 
    \(LinearCoeffTrF[uv_, pq_, rs_, x_, y_, z_, dx_, dy_, dz_] := 
      LinearCoeffTrF[uv, pq\[CirclePlus]rs, rs, x\ y\  - z, y, x, 
          x\ dy + dx\ y - dz, dy, dx] /; 
        pq\[CirclePlus]rs <= uv\), "\[IndentingNewLine]", 
    \(\(LinearCoeffTrF[uv_, mu_] := 
        LinearCoeffTrF[uv, 0/1, 1/1, \(-I\)\ mu, \(-I\)\ mu + 2  I, 
          2, \(-I\), \(-I\), 0];\)\), "\[IndentingNewLine]", 
    \(\(DTrF[uv_, 
          mu_] := \(LinearCoeffTrF[uv, 
            mu]\)\[LeftDoubleBracket]2\[RightDoubleBracket];\)\), "\
\[IndentingNewLine]", 
    \(\(RecursiveOnlyDTrF[uv_, mu_Complex] := DTrF[uv, mu];\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(DTrF\)\" is similar to \
existing symbol \"\!\(TrF\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(RecursiveOnlyDTrF\)\" \
is similar to existing symbol \"\!\(RecursiveOnlyTrF\)\"."\)], "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sequence computation", "Subsection"],

Cell[TextData[{
  "This is a slightly more sophisticated version of the boundary computation \
algorithm in my thesis. It works on any given specifier. A specifier here is \
a pair {seq,guess} where seq is a list of elements {f,t}. For each {f,t} the \
program solves the f-trace == t. This can then be used for plotting the \
boundary of for plotting pleating rays. Rather than allowing ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to turn the trace function into a polynomial and work with that (which is \
slow and unstable), I have used the RecursiveOnlyTrF function in FindRoot. \
Normally FindRoot would symbolically compute the derivative of the trace \
function and then use this polynomial to compute the trace derivative. Faced \
with only a recursive function definition though, FindRoot cannot work out \
the derivative, and so you have to specify. This is done by specifying \
Jacobian->{{RecursiveOnlyDTrF[f,mu]}}."
}], "Text"],

Cell[BoxData[{
    \(\(ComputeSequence[inseq_, initialmu_] := 
        Module[{initmu, outseq, f, t, i}, \[IndentingNewLine]initmu = 
            initialmu; \[IndentingNewLine]outseq = {}; \[IndentingNewLine]For[
            i = 1, i \[LessEqual] 
              Length[inseq], \(i++\), \[IndentingNewLine]f = 
              inseq\[LeftDoubleBracket]i, 
                1\[RightDoubleBracket]; \[IndentingNewLine]t = 
              inseq\[LeftDoubleBracket]i, 
                2\[RightDoubleBracket]; \[IndentingNewLine]initmu = 
              mu /. FindRoot[
                  RecursiveOnlyTrF[f, mu] \[Equal] t, {mu, initmu}, 
                  Jacobian \[Rule] {{RecursiveOnlyDTrF[f, mu]}}, 
                  MaxIterations \[Rule] 100]; \[IndentingNewLine]outseq = 
              Append[outseq, {f, t, 
                  initmu}];\[IndentingNewLine]]; \[IndentingNewLine]outseq\
\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(ComputeSequence[specifier_List] := 
        ComputeSequence[Sequence @@ specifier];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Boundary sequences", "Subsection"],

Cell["\<\
InitialBoundarySpecifier[qmax] just specifies that ComputeSequence should \
draw all the cusps between 0 and 1 with q<=qmax. GetBoundarySpecifier takes \
an already computed boundary (this is necessary to establish the initial \
guess), and specifies that all fractions between start and end with q<=qmax \
should be drawn.\
\>", "Text"],

Cell[BoxData[{
    \(\(InitialBoundarySpecifier[
          qmax_] := {\({#1, 2. } &\) /@ FareyList[qmax], 
          2.  I};\)\), "\[IndentingNewLine]", 
    \(\(GetBoundarySpecifier[seq_, start_, end_, qmax_] := 
        Module[{b, initmu}, \[IndentingNewLine]b = 
            Select[seq, #1\[LeftDoubleBracket]1\[RightDoubleBracket] \
\[LessEqual] 
                    end && #1\[LeftDoubleBracket]1\[RightDoubleBracket] \
\[GreaterEqual] start &]; \[IndentingNewLine]initmu = 
            b\[LeftDoubleBracket]1, 
              3\[RightDoubleBracket]; \[IndentingNewLine]{Function[
                z, {z, 2. }] /@ 
              CompleteFareySubdivision[\(#1\[LeftDoubleBracket]1\
\[RightDoubleBracket] &\) /@ b, qmax], 
            initmu}\[IndentingNewLine]];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pleating ray sequences", "Subsection"],

Cell["\<\
GetPleatingRaySpecifier gives a specifier for the f-pleating ray which starts \
at initmu, with numpoints points, spaced a distance eps*td*r^n apart, where \
td is the trace derivative at the f-cusp, r is a number slightly bigger than \
1 and n is the point number. There are decent reasons for thinking this gives \
you a nice chunk of pleating ray without going over the top. eps should be \
proportionate to the size of the viewing region. GetAllPleatingRaySpecifiers \
does this for a given piece of boundary for all p/q with q<=qmax.\
\>", "Text"],

Cell[BoxData[{
    \(\(GetPleatingRaySpecifier[f_, initmu_, numpoints_:  100, eps_:  0.1, 
          r_:  1.02] := 
        Module[\[IndentingNewLine]{td, t, dt, spec}, \[IndentingNewLine]td = 
            Abs[RecursiveOnlyDTrF[f, 
                initmu]]; \[IndentingNewLine]spec = {}; \[IndentingNewLine]t \
= 2. ; \[IndentingNewLine]dt = eps*td; \[IndentingNewLine]For[i = 0, 
            i < numpoints, \(i++\), \[IndentingNewLine]spec = 
              Append[spec, {f, t}]; \[IndentingNewLine]t += 
              dt; \[IndentingNewLine]dt *= 
              r;\[IndentingNewLine]]; \[IndentingNewLine]{spec, 
            initmu}\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(GetAllPleatingRaySpecifiers[bdyseq_, qmax_, numpoints_:  100, 
          eps_:  0.1] := 
        Module[\[IndentingNewLine]{b}, \[IndentingNewLine]b = 
            Select[bdyseq, 
              Denominator[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] \
\[LessEqual] 
                  qmax &]; \[IndentingNewLine]\(GetPleatingRaySpecifier[#1\
\[LeftDoubleBracket]1\[RightDoubleBracket], #1\[LeftDoubleBracket]3\
\[RightDoubleBracket], numpoints, eps] &\) /@ 
            b\[IndentingNewLine]];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Single cusps using pleating rays", "Subsection"],

Cell["\<\
FindCuspPleating finds the f=p/q cusp by moving down the pleating ray from \
(roughly) where it intersects the line Im(mu)=10. It turns out that starting \
from the line Im(mu)=3 converges to the wrong root for large q, but Im(mu)=10 \
seems to always work. See the picture of the real loci below for an idea as \
to why you might pick up the wrong root for large q. The procedure below \
decreases the target trace by a factor of 3/4 each step until a certain level \
of accuracy is attained, doing one Newton's method iteration each time. This \
seems to work, but some tweaking might conceivably be necessary.\
\>", "Text"],

Cell[BoxData[
    \(\(FindCuspPleating[f_] := 
        Module[{t, dt, t0, m0, mulfac}, \[IndentingNewLine]t[mu_Complex] := 
            RecursiveOnlyTrF[f, mu]; \[IndentingNewLine]dt[mu_Complex] := 
            RecursiveOnlyDTrF[f, mu]; \[IndentingNewLine]m0 = 
            2.  f + 10.  I; \[IndentingNewLine]t0 = 
            Re[t[m0]]; \[IndentingNewLine]mulfac =  .75; \
\[IndentingNewLine]While[
            Abs[t[m0] - 2. ] > 0.0001, \[IndentingNewLine]m0 = 
              m0 - \((t[m0] - t0)\)/dt[m0]; \[IndentingNewLine]t0 = 
              2.  + mulfac*\((t0 - 
                      2)\);\[IndentingNewLine]]; \[IndentingNewLine]m0\
\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["All cusps and real loci", "Subsection"],

Cell[TextData[{
  "AllRoots gives a list of all the roots to trace=t, note that because the \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " NSolve function requires a polynomial input, the recursive form of the \
trace function cannot be used, and so we are stuck with the numerical \
precision errors that come into effect if q>=23 or thereabouts."
}], "Text"],

Cell[BoxData[
    \(\(AllRoots[f_, t_] := 
        mu /. NSolve[TrF[f, mu] \[Equal] t, mu];\)\)], "Input"],

Cell["\<\
AllParabolics gives a list of all solutions to trace=\[PlusMinus]2. \
ComputeAllParabolics gives a list of elements {p/q,parabs} where q<=qmax and \
parabs is the corresponding set of parabolic points\
\>", "Text"],

Cell[BoxData[{
    \(\(AllParabolics[f_] := 
        Union[AllRoots[f, 2], 
          AllRoots[f, \(-2\)]];\)\), "\[IndentingNewLine]", 
    \(\(ComputeAllParabolics[
          qmax_] := \({#1, AllParabolics[#1] + 0.  I /. CpxToPair} &\) /@ 
          FareyList[qmax];\)\)}], "Input"],

Cell["\<\
AllRealLoci computes the roots of trace=t for a range of t designed to output \
a shape of approximate radius approxrad with 2n points per branch (so 2nq \
points in total for f=p/q). The complicated bits of this function are just a \
heuristic method for making sure the points are roughly evenly spaced (based \
on some reasonable assumptions which I won't go into here). Replacing \
Denominator[f] with Plus@@ContinuedFraction[f] might be more realistic for \
large denominators.\
\>", "Text"],

Cell[BoxData[
    \(\(AllRealLoci[f_, approxrad_, n_] := 
        Flatten[Union[\(AllRoots[
                  f, #1] &\) /@ \((\(Function[z, 
                    Join[z, \(-z\)]]\)[\((Range[0, n]/n)\)^\((Denominator[
                          f])\)*Abs[
                      TrF[f, approxrad\ I + 2.  f]]])\)]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting", "Subsection"],

Cell["\<\
The most important routine here is the ComputeAndPlot routine below, the \
others are more technical.\
\>", "Text"],

Cell["This just plots a sequence outputted by ComputeSequence", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotSequence[seq_, options___] := 
        ListPlot[\((\(#1\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
                seq)\) /. CpxToPair, PlotJoined \[Rule] True, 
          AspectRatio \[Rule] Automatic, options];\)\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(PlotSequence\)\" is \
similar to existing symbol \"\!\(SlotSequence\)\"."\)], "Message"]
}, Open  ]],

Cell[TextData[{
  "Returns a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Graphics object consisting of a list of plots of the sequences making up \
multiseq. Apply it to the output of \
ComputeSequence/@GetAllPleatingRaySpecifiers. This function will not display \
anything, you have to use Show[...,DisplayFunction->$DisplayFunction]."
}], "Text"],

Cell[BoxData[
    \(\(GfxMultiSequence[multiseq_, options___] := 
        Module[\[IndentingNewLine]{g, 
            seq}, \[IndentingNewLine]g = {}; \[IndentingNewLine]For[i = 1, 
            i \[LessEqual] 
              Length[multiseq], \(i++\), \[IndentingNewLine]seq = 
              multiseq\[LeftDoubleBracket]
                i\[RightDoubleBracket]; \[IndentingNewLine]g = 
              Append[g, 
                PlotSequence[seq, options, 
                  DisplayFunction \[Rule] 
                    Identity]];\[IndentingNewLine]]; \[IndentingNewLine]g\
\[IndentingNewLine]];\)\)], "Input"],

Cell["\<\
Returns a Graphics object consisting of labels for the p/q fractions with \
q<=qmax\
\>", "Text"],

Cell[BoxData[
    \(\(GfxLabelsBoundarySequence[seq_, qmax_, opts___] := 
        Graphics[
          Join[{opts}, \(Text[#1\[LeftDoubleBracket]1\[RightDoubleBracket], \
#1\[LeftDoubleBracket]3\[RightDoubleBracket] /. CpxToPair] &\) /@ 
              Select[seq, 
                Function[z, 
                  Denominator[
                      z\[LeftDoubleBracket]1\[RightDoubleBracket]] \
\[LessEqual] qmax]]]];\)\)], "Input"],

Cell[TextData[{
  "Given a boundary specifier, this computes the boundary, and optionally the \
pleating rays, and shows it with optional labels. Options are \
ShowPleating->qmax to show all the pleating rays with q<=qmax; \
PleatingColour->col to give the pleating rays colour col, e.g. \
PleatingColour->RGBColour[1,0,0] for red; ShowLabels->qmax to label the p/q \
cusps with q<=qmax; LabelColour->col; PlotRange->range, see ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " documentation for more info; ZoomBox->{min,max} draws a box around the \
portion of the boundary with p/q between min and max; PleatingEpsilon->eps \
set the value of eps passed to the GetPleatingRaySpecifier function, the \
default makes it proportional to the viewing region. The function returns the \
computed boundary sequence which you can use for further plots."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ComputeAndPlot[bdyspec_, opts___] := 
        Module[\[IndentingNewLine]{bdyseq, g, rayqmax, rayspec, rayseq, 
            raycol, bdycol, labelsqmax, labelcol, plotrange, zoomrange, 
            subseq, zoomxmin, zoomxmax, zoomymin, zoomymax, 
            rayeps}, \[IndentingNewLine]bdyseq = 
            ComputeSequence[
              bdyspec]; \[IndentingNewLine]bdycol = \(BoundaryColour /. \
{opts}\) /. BoundaryColour \[Rule] 
                RGBColor[0, 0, 0.7]; \[IndentingNewLine]g = {PlotSequence[
                bdyseq, DisplayFunction \[Rule] Identity, 
                PlotStyle \[Rule] {bdycol}]}; \[IndentingNewLine]plotrange = \
{{Min[\(Re[#1\[LeftDoubleBracket]3\[RightDoubleBracket]] &\) /@ bdyseq], 
                Max[\(Re[#1\[LeftDoubleBracket]3\[RightDoubleBracket]] &\) /@ 
                    bdyseq]}, {Min[\(Im[#1\[LeftDoubleBracket]3\
\[RightDoubleBracket]] &\) /@ bdyseq], 
                Max[\(Im[#1\[LeftDoubleBracket]3\[RightDoubleBracket]] &\) /@ 
                    bdyseq]}}; \[IndentingNewLine]rayqmax = \(ShowPleating /. \
{opts}\) /. ShowPleating -> 0; \[IndentingNewLine]If[
            rayqmax > 
              0, \[IndentingNewLine]rayeps = \(PleatingEpsilon /. {opts}\) /. 
                PleatingEpsilon \[Rule] 
                  0.02*Max[
                      plotrange\[LeftDoubleBracket]1, 
                          2\[RightDoubleBracket] - 
                        plotrange\[LeftDoubleBracket]1, 
                          1\[RightDoubleBracket], 
                      plotrange\[LeftDoubleBracket]2, 
                          2\[RightDoubleBracket] - 
                        plotrange\[LeftDoubleBracket]2, 
                          1\[RightDoubleBracket]]; \[IndentingNewLine]raycol \
= \(PleatingColour /. {opts}\) /. 
                PleatingColour \[Rule] 
                  RGBColor[0.5, 0.5, 0.5]; \[IndentingNewLine]rayspec = 
              GetAllPleatingRaySpecifiers[bdyseq, rayqmax, 100, 
                rayeps]; \[IndentingNewLine]rayseq = 
              ComputeSequence /@ rayspec; \[IndentingNewLine]\(g = 
                Append[g, 
                  GfxMultiSequence[rayseq, 
                    PlotStyle \[Rule] {raycol}]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]labelsqmax = \(ShowLabels /. {opts}\) /. 
              ShowLabels \[Rule] 0; \[IndentingNewLine]If[
            labelsqmax > 
              0, \[IndentingNewLine]labelcol = \(LabelColour /. {opts}\) /. 
                LabelColour \[Rule] RGBColor[0, 0, 0]; \[IndentingNewLine]g = 
              Append[g, 
                GfxLabelsBoundarySequence[bdyseq, labelsqmax, 
                  labelcol]];\[IndentingNewLine]]; \
\[IndentingNewLine]plotrange = \(PlotRange /. {opts}\) /. 
              PlotRange \[Rule] 
                plotrange; \[IndentingNewLine]zoomrange = \(ZoomBox /. {opts}\
\) /. ZoomBox \[Rule] {}; \[IndentingNewLine]If[
            Length[zoomrange] > 0, \[IndentingNewLine]subseq = 
              Select[bdyseq, #1\[LeftDoubleBracket]1\[RightDoubleBracket] \
\[GreaterEqual] 
                      zoomrange\[LeftDoubleBracket]1\[RightDoubleBracket] && \
#1\[LeftDoubleBracket]1\[RightDoubleBracket] \[LessEqual] 
                      zoomrange\[LeftDoubleBracket]2\[RightDoubleBracket] &]; \
\[IndentingNewLine]If[
              Length[subseq] > 0, \[IndentingNewLine]zoomxmin = 
                Min[\(Re[#1\[LeftDoubleBracket]3\[RightDoubleBracket]] &\) /@ 
                    subseq]; \[IndentingNewLine]zoomxmax = 
                Max[\(Re[#1\[LeftDoubleBracket]3\[RightDoubleBracket]] &\) /@ 
                    subseq]; \[IndentingNewLine]zoomymin = 
                Min[\(Im[#1\[LeftDoubleBracket]3\[RightDoubleBracket]] &\) /@ 
                    subseq]; \[IndentingNewLine]zoomymax = 
                Max[\(Im[#1\[LeftDoubleBracket]3\[RightDoubleBracket]] &\) /@ 
                    subseq]; \[IndentingNewLine]g = 
                Prepend[g, 
                  Graphics[{RGBColor[0.8, 0.8, 0.8], 
                      Rectangle[{zoomxmin, zoomymin}, {zoomxmax, zoomymax}], 
                      RGBColor[0.5, 0.5, 0.5], 
                      Line[{{zoomxmin, zoomymin}, {zoomxmin, 
                            zoomymax}, {zoomxmax, zoomymax}, {zoomxmax, 
                            zoomymin}, {zoomxmin, 
                            zoomymin}}]}]];\[IndentingNewLine]];\
\[IndentingNewLine]]; \[IndentingNewLine]Show[g, 
            DisplayFunction \[Rule] $DisplayFunction, 
            PlotRange \[Rule] plotrange, Axes \[Rule] True, 
            AspectRatio \[Rule] 
              Automatic]; \
\[IndentingNewLine]bdyseq\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(zoomymin\)\" is similar \
to existing symbol \"\!\(zoomxmin\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(zoomymax\)\" is similar \
to existing symbol \"\!\(zoomxmax\)\"."\)], "Message"]
}, Open  ]],

Cell["\<\
Plots the output of ComputeAllParabolics shading points with hue p/q\
\>", "Text"],

Cell[BoxData[
    \(\(PlotAllParabolics[allparablist_] := 
        Show[Function[froots, 
              Graphics[{Hue[
                    froots\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                  Point /@ 
                    froots\[LeftDoubleBracket]2\[RightDoubleBracket]}]] /@ 
            allparablist];\)\)], "Input"],

Cell["\<\
Compute and plots the real loci of f=p/q-trace, output is approximate radius \
approxrad, 2nq points in total\
\>", "Text"],

Cell[BoxData[
    \(\(RealLociDiagram[f_, approxrad_, n_] := 
        ListPlot[AllRealLoci[f, approxrad, n] + 0.  I /. CpxToPair, 
          AspectRatio \[Rule] Automatic, PlotRange \[Rule] All];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example usage", "Section"],

Cell[CellGroupData[{

Cell["Zoom sequence", "Subsection"],

Cell["\<\
First of all, compute the [0,1] interval of the Maskit slice up to q=40. Each \
plot shows the region which will be shown in the next plot\
\>", "Text"],

Cell[BoxData[
    \(\(bdy40 = 
        ComputeAndPlot[InitialBoundarySpecifier[40], ShowLabels \[Rule] 8, 
          ZoomBox \[Rule] {5/11, 6/11}, 
          ShowPleating \[Rule] 15];\)\)], "Input"],

Cell["Now zoom into the region [5/11,6/11] around the 1/2-cusp.", "Text"],

Cell[BoxData[
    \(\(subbdy = 
        ComputeAndPlot[GetBoundarySpecifier[bdy40, 5/11, 6/11, 240], 
          ShowLabels \[Rule] 25, ZoomBox \[Rule] {8/17, 9/19}, 
          ShowPleating \[Rule] 40];\)\)], "Input"],

Cell["Finally zoom into the region [8/17,9/19]", "Text"],

Cell[BoxData[
    \(\(subbdy2 = 
        ComputeAndPlot[GetBoundarySpecifier[subbdy, 8/17, 9/19, 900], 
          ShowLabels \[Rule] 100, ShowPleating \[Rule] 300];\)\)], "Input"],

Cell["You could easily go on...", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Parabolic dust", "Subsection"],

Cell[BoxData[
    \(\(PlotAllParabolics[ComputeAllParabolics[20]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Real loci", "Subsection"],

Cell[BoxData[
    \(\(RealLociDiagram[3/7, 4, 100];\)\)], "Input"],

Cell[BoxData[
    \(\(RealLociDiagram[3/13, 4, 100];\)\)], "Input"],

Cell[BoxData[
    \(\(RealLociDiagram[7/20, 4, 100];\)\)], "Input"],

Cell[BoxData[
    \(\(RealLociDiagram[8/21, 3, 200];\)\)], "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 827}},
WindowSize->{863, 731},
WindowMargins->{{213, Automatic}, {Automatic, 24}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 34, 0, 105, "Title"],
Cell[1776, 53, 36, 0, 64, "Subtitle"],
Cell[1815, 55, 118, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[1958, 62, 23, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[2006, 66, 36, 0, 47, "Subsection"],
Cell[2045, 68, 249, 4, 52, "Text"],
Cell[2297, 74, 82, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2416, 80, 37, 0, 31, "Subsection"],
Cell[2456, 82, 1015, 15, 128, "Text"],
Cell[3474, 99, 909, 19, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4420, 123, 37, 0, 31, "Subsection"],
Cell[4460, 125, 536, 10, 71, "Text"],
Cell[4999, 137, 680, 12, 130, "Input"],
Cell[5682, 151, 499, 8, 71, "Text"],

Cell[CellGroupData[{
Cell[6206, 163, 1112, 20, 190, "Input"],
Cell[7321, 185, 180, 3, 24, "Message"],
Cell[7504, 190, 206, 3, 42, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7759, 199, 42, 0, 31, "Subsection"],
Cell[7804, 201, 955, 15, 128, "Text"],
Cell[8762, 218, 1040, 18, 270, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9839, 241, 40, 0, 31, "Subsection"],
Cell[9882, 243, 347, 6, 52, "Text"],
Cell[10232, 251, 780, 15, 130, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11049, 271, 44, 0, 31, "Subsection"],
Cell[11096, 273, 562, 8, 90, "Text"],
Cell[11661, 283, 1202, 21, 370, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12900, 309, 54, 0, 31, "Subsection"],
Cell[12957, 311, 636, 9, 90, "Text"],
Cell[13596, 322, 677, 12, 250, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14310, 339, 45, 0, 31, "Subsection"],
Cell[14358, 341, 374, 8, 52, "Text"],
Cell[14735, 351, 106, 2, 30, "Input"],
Cell[14844, 355, 224, 4, 52, "Text"],
Cell[15071, 361, 284, 6, 50, "Input"],
Cell[15358, 369, 506, 8, 71, "Text"],
Cell[15867, 379, 327, 6, 90, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16231, 390, 30, 0, 31, "Subsection"],
Cell[16264, 392, 125, 3, 33, "Text"],
Cell[16392, 397, 71, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[16488, 401, 260, 4, 50, "Input"],
Cell[16751, 407, 197, 3, 42, "Message"]
}, Open  ]],
Cell[16963, 413, 363, 8, 52, "Text"],
Cell[17329, 423, 606, 12, 190, "Input"],
Cell[17938, 437, 107, 3, 33, "Text"],
Cell[18048, 442, 430, 9, 70, "Input"],
Cell[18481, 453, 868, 14, 109, "Text"],

Cell[CellGroupData[{
Cell[19374, 471, 4673, 81, 790, "Input"],
Cell[24050, 554, 189, 3, 42, "Message"],
Cell[24242, 559, 189, 3, 42, "Message"]
}, Open  ]],
Cell[24446, 565, 92, 2, 33, "Text"],
Cell[24541, 569, 336, 7, 50, "Input"],
Cell[24880, 578, 133, 3, 33, "Text"],
Cell[25016, 583, 210, 3, 50, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[25275, 592, 32, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[25332, 596, 35, 0, 47, "Subsection"],
Cell[25370, 598, 162, 3, 33, "Text"],
Cell[25535, 603, 198, 4, 50, "Input"],
Cell[25736, 609, 73, 0, 33, "Text"],
Cell[25812, 611, 216, 4, 50, "Input"],
Cell[26031, 617, 56, 0, 33, "Text"],
Cell[26090, 619, 179, 3, 30, "Input"],
Cell[26272, 624, 41, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[26350, 629, 36, 0, 31, "Subsection"],
Cell[26389, 631, 81, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26507, 637, 31, 0, 31, "Subsection"],
Cell[26541, 639, 66, 1, 30, "Input"],
Cell[26610, 642, 67, 1, 30, "Input"],
Cell[26680, 645, 67, 1, 30, "Input"],
Cell[26750, 648, 67, 1, 30, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

