(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28319,        626]*)
(*NotebookOutlinePosition[     28973,        649]*)
(*  CellTagsIndexPosition[     28929,        645]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Random Walk Experiment", "Title"],

Cell["\<\
This program tests whether or not a proof based on the idea that the \
spiralling degrees of the pleating rays corresponding to the partial \
approximants of a number form an approximate nontrivial random walk.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Data Loading", "Section"],

Cell["\<\
Automatically attempt to load data. If the file tda2000.txt is not in a \
subdirectory of your home directory, simply change the next expression to the \
line:
<<\"directory\\\\tda2000.txt\"
where 'directory' is the directory where the file tda2000.txt is kept, and \
all symbols \\ are replaced by \\\\.\
\>", "Text"],

Cell[BoxData[{
    \(\(filenames = 
        FileNames["\<tda2000.txt\>", $HomeDirectory, 
          Infinity];\)\), "\[IndentingNewLine]", 
    \(\(If[
        Length[filenames] \[GreaterEqual] 
          1, \[IndentingNewLine]\(Get[
            filenames\[LeftDoubleBracket]1\[RightDoubleBracket]];\)];\)\)}], \
"Input"],

Cell["\<\
These two lines turn the table loaded above into a function \
TraceDeriv[p/q].\
\>", "Text"],

Cell[BoxData[
    \(\(TraceDeriv[1] := TraceDeriv[0];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((\(TraceDeriv[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] = #1\
\[LeftDoubleBracket]2\[RightDoubleBracket];\))\) &\) /@ 
        tracederivatives;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Experiment", "Section"],

Cell[CellGroupData[{

Cell["Code", "Subsection"],

Cell["\<\
This function builds a table of samples which are pairs (r1,r2,a) of \
sequential partial approximants to uniformly randomly chosen numbers in [0,1] \
with the limitation that the denominators must be smaller than maxdenom, this \
pair has the corresponding partial quotient a\
\>", "Text"],

Cell[BoxData[
    \(\(BuildGlobalSampleTable[numtrials_, maxdenom_] := 
        Module[{cft, approximants, semisamlist}, \[IndentingNewLine]cft = 
            ContinuedFraction[
              Table[Random[], {numtrials}]]; \[IndentingNewLine]approximants \
= \(Select[#1, Function[x, 
                    Denominator[x] < 
                      maxdenom]] &\) /@ \((\(\((FromContinuedFraction /@ 
                        Table[Take[#1, i], {i, 1, Length[#1]}])\) &\) /@ 
                  cft)\); \[IndentingNewLine]semisamlist = 
            Table[{Take[cft\[LeftDoubleBracket]i\[RightDoubleBracket], 
                  Length[approximants\[LeftDoubleBracket]
                      i\[RightDoubleBracket]]], 
                approximants\[LeftDoubleBracket]i\[RightDoubleBracket]}, {i, 
                1, Length[cft]}]; \[IndentingNewLine]Union[
            Flatten[\(Table[{#1\[LeftDoubleBracket]2, 
                        i - 1\[RightDoubleBracket], #1\[LeftDoubleBracket]2, 
                        i\[RightDoubleBracket], #1\[LeftDoubleBracket]1, 
                        i\[RightDoubleBracket]}, {i, 2, 
                      Length[#1\[LeftDoubleBracket]1\[RightDoubleBracket]]}] \
&\) /@ semisamlist, 1]]\[IndentingNewLine]];\)\)], "Input"],

Cell["\<\
This function gives the difference in the spiralling degrees of the pleating \
rays at r1 and r2\
\>", "Text"],

Cell[BoxData[
    \(\(\[CapitalDelta]\[CapitalTheta][{r1_, r2_, a_}] := 
        Abs[Arg[TraceDeriv[r2]/TraceDeriv[r1]]];\)\)], "Input"],

Cell["This long computational step builds the sample table", "Text"],

Cell[BoxData[
    \(NumTrials = 30000; MaxDenom = 2000;\)], "Input"],

Cell[BoxData[
    \(\(GlobalSampleTable = 
        BuildGlobalSampleTable[NumTrials, MaxDenom];\)\)], "Input"],

Cell["\<\
This step selects subsets of the sample table satisfying various conditions \
on the partial quotients\
\>", "Text"],

Cell[BoxData[
    \(\(\(\((\(SampleTable[#1, Equal] = 
                Select[GlobalSampleTable, 
                  Function[x, 
                    x\[LeftDoubleBracket]3\[RightDoubleBracket] \[Equal] \
#1]];\))\) &\) /@ Range[20];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((\(SampleTable[#1, GreaterEqual] = 
                Select[GlobalSampleTable, 
                  Function[x, 
                    x\[LeftDoubleBracket]3\[RightDoubleBracket] >= #1]];\))\) \
&\) /@ Range[20];\)\)], "Input"],

Cell["\<\
Generate the summary stats by computing \[CapitalDelta]\[CapitalTheta] \
applied to the sample tables\
\>", "Text"],

Cell[BoxData[
    \(\(For[n = 1, 
        n \[LessEqual] 
          20, \(n++\), \[IndentingNewLine]stE = \(\[CapitalDelta]\
\[CapitalTheta][#1] &\) /@ 
            SampleTable[n, 
              Equal]; \[IndentingNewLine]stGE = \(\[CapitalDelta]\
\[CapitalTheta][#1] &\) /@ 
            SampleTable[n, GreaterEqual]; \[IndentingNewLine]SummaryStats[
            n] = {n, Min[stE], Max[stE], Length[stE], Min[stGE], Max[stGE], 
            Length[stGE]};\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(RestrictedSampleSet[n_, condn_, qmin_, qmax_] := 
        Select[SampleTable[n, condn], 
          Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]] > qmin && 
              Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]] < 
                qmax &];\)\)], "Input"],

Cell["\<\
For the purposes of working out how much the summary stats depend on small \
denominator rationals, compute \[CapitalDelta]\[CapitalTheta] for rationals \
whose denominators q satisfies 0<q<200; 200<q<700; 700<q<2000. The idea being \
if the stats are about the same, that lends some support to their being \
universal. At least, that's about as much support as we can hope for with the \
limitation on the denominators.\
\>", "Text"],

Cell[BoxData[
    \(\(For[n = 1, 
        n \[LessEqual] 
          20, \(n++\), \[IndentingNewLine]stE = \(\[CapitalDelta]\
\[CapitalTheta][#1] &\) /@ 
            RestrictedSampleSet[n, Equal, 200, 
              700]; \[IndentingNewLine]stGE = \
\(\[CapitalDelta]\[CapitalTheta][#1] &\) /@ 
            RestrictedSampleSet[n, GreaterEqual, 200, 
              700]; \[IndentingNewLine]SummaryStats[n, 200, 700] = {n, 
            Min[stE], Max[stE], Length[stE], Min[stGE], Max[stGE], 
            Length[stGE]}; \[IndentingNewLine]stE = \(\[CapitalDelta]\
\[CapitalTheta][#1] &\) /@ 
            RestrictedSampleSet[n, Equal, 0, 
              200]; \[IndentingNewLine]stGE = \
\(\[CapitalDelta]\[CapitalTheta][#1] &\) /@ 
            RestrictedSampleSet[n, GreaterEqual, 0, 
              200]; \[IndentingNewLine]SummaryStats[n, 0, 200] = {n, 
            Min[stE], Max[stE], Length[stE], Min[stGE], Max[stGE], 
            Length[stGE]}; \[IndentingNewLine]stE = \(\[CapitalDelta]\
\[CapitalTheta][#1] &\) /@ 
            RestrictedSampleSet[n, Equal, 700, 
              2000]; \[IndentingNewLine]stGE = \(\[CapitalDelta]\
\[CapitalTheta][#1] &\) /@ 
            RestrictedSampleSet[n, GreaterEqual, 700, 
              2000]; \[IndentingNewLine]SummaryStats[n, 700, 2000] = {n, 
            Min[stE], Max[stE], Length[stE], Min[stGE], Max[stGE], 
            Length[stGE]};\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Subsection"],

Cell["\<\
Summary stats for \[CapitalDelta]\[CapitalTheta] applied to the full sample \
table\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[SummaryStats[n], {n, 1, 20}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "0", "0.2298945805304214`", "30800", "0", 
            "1.5676875191569581`", "71787"},
          {"2", "7.445500702393863`*^-10", "0.15189311279643478`", "12125", 
            "7.445500702393863`*^-10", "1.5676875191569581`", "40987"},
          {"3", "0.05195545788059537`", "0.3350390835422475`", "6633", 
            "0.05195545788059537`", "1.5676875191569581`", "28862"},
          {"4", "0.25911922418919126`", "0.5129354711726744`", "4081", 
            "0.25911922418919126`", "1.5676875191569581`", "22229"},
          {"5", "0.44970057631459015`", "0.6628668871649726`", "2793", 
            "0.44970057631459015`", "1.5676875191569581`", "18148"},
          {"6", "0.6069543154347786`", "0.7823291902482497`", "2058", 
            "0.6069543154347786`", "1.5676875191569581`", "15355"},
          {"7", "0.7318794806095382`", "0.8775324942174965`", "1609", 
            "0.7318794806095382`", "1.5676875191569581`", "13297"},
          {"8", "0.8307837565401166`", "0.9531965550862663`", "1234", 
            "0.8307837565401166`", "1.5676875191569581`", "11688"},
          {"9", "0.9100192049787418`", "1.0144297738185908`", "972", 
            "0.9100192049787418`", "1.5676875191569581`", "10454"},
          {"10", "0.974477306566102`", "1.0653952741558337`", "828", 
            "0.974477306566102`", "1.5676875191569581`", "9482"},
          {"11", "1.0277701854941421`", "1.1079235466755983`", "741", 
            "1.0277701854941421`", "1.5676875191569581`", "8654"},
          {"12", "1.0724751850594085`", "1.1439874986606635`", "588", 
            "1.0724751850594085`", "1.5676875191569581`", "7913"},
          {"13", "1.1104591882508383`", "1.1747102815088895`", "484", 
            "1.1104591882508383`", "1.5676875191569581`", "7325"},
          {"14", "1.1431044019623227`", "1.2013997882281353`", "459", 
            "1.1431044019623227`", "1.5676875191569581`", "6841"},
          {"15", "1.1714537408791352`", "1.2245134521145953`", "404", 
            "1.1714537408791352`", "1.5676875191569581`", "6382"},
          {"16", "1.1963058059303653`", "1.2453206624208102`", "361", 
            "1.1963058059303653`", "1.5676875191569581`", "5978"},
          {"17", "1.2182802426992625`", "1.2635030795331976`", "308", 
            "1.2182802426992625`", "1.5676875191569581`", "5617"},
          {"18", "1.2377801955304335`", "1.279825487177051`", "282", 
            "1.2377801955304335`", "1.5676875191569581`", "5309"},
          {"19", "1.2552652827883237`", "1.2946287297769528`", "254", 
            "1.2552652827883237`", "1.5676875191569581`", "5027"},
          {"20", "1.2710067939978171`", "1.3080363534747985`", "215", 
            "1.2710067939978171`", "1.5676875191569581`", "4773"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Summary stats for \[CapitalDelta]\[CapitalTheta] applied to the 0<q<200 \
sample table\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[SummaryStats[n, 0, 200], {n, 1, 20}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "0", "0.22970027302082538`", "7711", "0", 
            "1.540646170749315`", "16475"},
          {"2", "7.445500702393863`*^-10", "0.1516378669255123`", "2763", 
            "7.445500702393863`*^-10", "1.540646170749315`", "8764"},
          {"3", "0.05224342025050078`", "0.3345237002477352`", "1466", 
            "0.05224342025050078`", "1.540646170749315`", "6001"},
          {"4", "0.2594480874661482`", "0.5122022676940943`", "871", 
            "0.2594480874661482`", "1.540646170749315`", "4535"},
          {"5", "0.4498443341765451`", "0.6623562942507166`", "582", 
            "0.4498443341765451`", "1.540646170749315`", "3664"},
          {"6", "0.6070996532355182`", "0.7818230092580253`", "407", 
            "0.6070996532355182`", "1.540646170749315`", "3082"},
          {"7", "0.731941410548983`", "0.8769023457349373`", "334", 
            "0.731941410548983`", "1.540646170749315`", "2675"},
          {"8", "0.8308876940702649`", "0.952258167314874`", "255", 
            "0.8308876940702649`", "1.540646170749315`", "2341"},
          {"9", "0.9100706927947555`", "1.01365634531273`", "203", 
            "0.9100706927947555`", "1.540646170749315`", "2086"},
          {"10", "0.9745450016431357`", "1.0646816065461189`", "165", 
            "0.9745450016431357`", "1.540646170749315`", "1883"},
          {"11", "1.0279054565638632`", "1.1070956895322699`", "148", 
            "1.0279054565638632`", "1.540646170749315`", "1718"},
          {"12", "1.0735091136366288`", "1.143031175430275`", "115", 
            "1.0735091136366288`", "1.540646170749315`", "1570"},
          {"13", "1.11163495660122`", "1.173938561064591`", "105", 
            "1.11163495660122`", "1.540646170749315`", "1455"},
          {"14", "1.1443975533337818`", "1.2006403302166688`", "94", 
            "1.1443975533337818`", "1.540646170749315`", "1350"},
          {"15", "1.1725149123890966`", "1.2239760874209615`", "77", 
            "1.1725149123890966`", "1.540646170749315`", "1256"},
          {"16", "1.1971800959559926`", "1.2445430587651483`", "71", 
            "1.1971800959559926`", "1.540646170749315`", "1179"},
          {"17", "1.2189864894942306`", "1.2628056951215731`", "61", 
            "1.2189864894942306`", "1.540646170749315`", "1108"},
          {"18", "1.2384003040499612`", "1.278919855242841`", "57", 
            "1.2384003040499612`", "1.540646170749315`", "1047"},
          {"19", "1.2557924851258166`", "1.2937885212411522`", "50", 
            "1.2557924851258166`", "1.540646170749315`", "990"},
          {"20", "1.2714616138437487`", "1.3072140407355706`", "44", 
            "1.2714616138437487`", "1.540646170749315`", "940"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Summary stats for \[CapitalDelta]\[CapitalTheta] applied to the 200<q<700 \
sample table\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[SummaryStats[n, 200, 700], {n, 1, 20}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "0.00001233299830244833`", "0.22984666898118403`", "12004", 
            "3.5585577995819093`*^-9", "1.562188019197482`", "28740"},
          {"2", "3.5585577995819093`*^-9", "0.15184204740115195`", "4905", 
            "3.5585577995819093`*^-9", "1.562188019197482`", "16736"},
          {"3", "0.05195545788059537`", "0.33493128425813395`", "2687", 
            "0.05195545788059537`", "1.562188019197482`", "11831"},
          {"4", "0.25911922418919126`", "0.5129144129530686`", "1675", 
            "0.25911922418919126`", "1.562188019197482`", "9144"},
          {"5", "0.44970057631459015`", "0.662812781405802`", "1163", 
            "0.44970057631459015`", "1.562188019197482`", "7469"},
          {"6", "0.60701995152046`", "0.7822208635818707`", "835", 
            "0.60701995152046`", "1.562188019197482`", "6306"},
          {"7", "0.7318794806095382`", "0.8775324942174965`", "677", 
            "0.7318794806095382`", "1.562188019197482`", "5471"},
          {"8", "0.8308149380245755`", "0.9530390140800085`", "493", 
            "0.8308149380245755`", "1.562188019197482`", "4794"},
          {"9", "0.9100303230984411`", "1.0143806263292525`", "421", 
            "0.9100303230984411`", "1.562188019197482`", "4301"},
          {"10", "0.9744891317533251`", "1.065313499918809`", "315", 
            "0.9744891317533251`", "1.562188019197482`", "3880"},
          {"11", "1.0277792165265613`", "1.1077528859689794`", "310", 
            "1.0277792165265613`", "1.562188019197482`", "3565"},
          {"12", "1.0724751850594085`", "1.1436509574802378`", "236", 
            "1.0724751850594085`", "1.562188019197482`", "3255"},
          {"13", "1.110459322008512`", "1.1747102815088895`", "187", 
            "1.110459322008512`", "1.562188019197482`", "3019"},
          {"14", "1.143105215683134`", "1.2013997882281353`", "175", 
            "1.143105215683134`", "1.562188019197482`", "2832"},
          {"15", "1.1714537408791352`", "1.2243757282305845`", "164", 
            "1.1714537408791352`", "1.562188019197482`", "2657"},
          {"16", "1.1963058059303653`", "1.2451050283131362`", "155", 
            "1.1963058059303653`", "1.562188019197482`", "2493"},
          {"17", "1.2182850060473425`", "1.2634363628007133`", "126", 
            "1.2182850060473425`", "1.562188019197482`", "2338"},
          {"18", "1.23778198351086`", "1.2797657238029885`", "122", 
            "1.23778198351086`", "1.562188019197482`", "2212"},
          {"19", "1.2552652827883237`", "1.2943208861294015`", "107", 
            "1.2552652827883237`", "1.562188019197482`", "2090"},
          {"20", "1.2710354206524066`", "1.3078671182197228`", "73", 
            "1.2710354206524066`", "1.562188019197482`", "1983"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Summary stats for \[CapitalDelta]\[CapitalTheta] applied to the 700<q<2000 \
sample table\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[SummaryStats[n, 700, 2000], {n, 1, 20}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "1.682339772199004`*^-6", "0.2298945805304214`", "11049", 
            "1.682339772199004`*^-6", "1.5676875191569581`", "26490"},
          {"2", "0.000013480290172539595`", "0.15189311279643478`", "4442", 
            "0.000013480290172539595`", "1.5676875191569581`", "15441"},
          {"3", "0.0519792598931326`", "0.3350390835422475`", "2470", 
            "0.0519792598931326`", "1.5676875191569581`", "10999"},
          {"4", "0.25914273125505727`", "0.5129354711726744`", "1529", 
            "0.25914273125505727`", "1.5676875191569581`", "8529"},
          {"5", "0.44970162610353637`", "0.6628668871649726`", "1046", 
            "0.44970162610353637`", "1.5676875191569581`", "7000"},
          {"6", "0.6069543154347786`", "0.7823291902482497`", "813", 
            "0.6069543154347786`", "1.5676875191569581`", "5954"},
          {"7", "0.7318893452602617`", "0.8773619529519436`", "598", 
            "0.7318893452602617`", "1.5676875191569581`", "5141"},
          {"8", "0.8307837565401166`", "0.9531965550862663`", "485", 
            "0.8307837565401166`", "1.5676875191569581`", "4543"},
          {"9", "0.9100192049787418`", "1.0144297738185908`", "347", 
            "0.9100192049787418`", "1.5676875191569581`", "4058"},
          {"10", "0.974477306566102`", "1.0653952741558337`", "347", 
            "0.974477306566102`", "1.5676875191569581`", "3711"},
          {"11", "1.0277701854941421`", "1.1079235466755983`", "281", 
            "1.0277701854941421`", "1.5676875191569581`", "3364"},
          {"12", "1.0725177363463088`", "1.1439874986606635`", "237", 
            "1.0725177363463088`", "1.5676875191569581`", "3083"},
          {"13", "1.1104591882508383`", "1.1741551014135145`", "192", 
            "1.1104591882508383`", "1.5676875191569581`", "2846"},
          {"14", "1.1431044019623227`", "1.2013115073696603`", "190", 
            "1.1431044019623227`", "1.5676875191569581`", "2654"},
          {"15", "1.1714588430285349`", "1.2245134521145953`", "162", 
            "1.1714588430285349`", "1.5676875191569581`", "2464"},
          {"16", "1.1964818011120042`", "1.2453206624208102`", "134", 
            "1.1964818011120042`", "1.5676875191569581`", "2302"},
          {"17", "1.2182802426992625`", "1.2635030795331976`", "121", 
            "1.2182802426992625`", "1.5676875191569581`", "2168"},
          {"18", "1.2377801955304335`", "1.279825487177051`", "103", 
            "1.2377801955304335`", "1.5676875191569581`", "2047"},
          {"19", "1.2552930171170085`", "1.2946287297769528`", "97", 
            "1.2552930171170085`", "1.5676875191569581`", "1944"},
          {"20", "1.2710067939978171`", "1.3080363534747985`", "98", 
            "1.2710067939978171`", "1.5676875191569581`", "1847"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
These pictures give an idea of how the samples are distributed. \
Unsurprisingly, there are more samples for smaller denominators, but the \
spread seems to be reasonably even otherwise.\
\>", "Text"],

Cell[BoxData[
    \(\(ListPlot[\({Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]],\
 Random[]} &\) /@ SampleTable[3, Equal], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]],\
 Random[]} &\) /@ SampleTable[10, Equal], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]],\
 Random[]} &\) /@ SampleTable[15, Equal], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]],\
 Random[]} &\) /@ SampleTable[20, Equal], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]],\
 Random[]} &\) /@ SampleTable[3, GreaterEqual], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]],\
 Random[]} &\) /@ SampleTable[10, GreaterEqual], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]],\
 Random[]} &\) /@ SampleTable[15, GreaterEqual], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]],\
 Random[]} &\) /@ SampleTable[20, GreaterEqual], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({#1\[LeftDoubleBracket]2\[RightDoubleBracket], 
              Random[]} &\) /@ SampleTable[5, Equal], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({#1\[LeftDoubleBracket]2\[RightDoubleBracket], 
              Random[]} &\) /@ SampleTable[5, GreaterEqual], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({#1\[LeftDoubleBracket]2\[RightDoubleBracket], 
              Random[]} &\) /@ SampleTable[15, Equal], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({#1\[LeftDoubleBracket]2\[RightDoubleBracket], 
              Random[]} &\) /@ SampleTable[15, GreaterEqual], 
        AspectRatio \[Rule] 1/4];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Summary Statistics", "Section"],

Cell["\<\
This table gives the minimum and maximum values of \[CapitalDelta]\
\[CapitalTheta] for some set of samples. The (=) columns are for when the \
partial quotients are equal to N, the (>=) columns are for when the partial \
quotients are greater than or equal to N.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[Table[SummaryStats[n], {n, 1, 20}], 
      TableHeadings \[Rule] {None, {"\<N\>", "\<min \[CapitalDelta]\
\[CapitalTheta] (=)\>", "\<max \[CapitalDelta]\[CapitalTheta] (=)\>", \
"\<samples (=)\>", "\<min \[CapitalDelta]\[CapitalTheta] (>=)\>", "\<max \
\[CapitalDelta]\[CapitalTheta] (>=)\>", \ "\<samples (>=)\>"}}]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"min \[CapitalDelta]\[CapitalTheta] (=)\"\>", "\<\
\"max \[CapitalDelta]\[CapitalTheta] (=)\"\>", "\<\"samples (=)\"\>", \
"\<\"min \[CapitalDelta]\[CapitalTheta] (>=)\"\>", "\<\"max \[CapitalDelta]\
\[CapitalTheta] (>=)\"\>", "\<\"samples (>=)\"\>"},
          {"1", "0", "0.2298945805304214`", "30800", "0", 
            "1.5676875191569581`", "71787"},
          {"2", "7.445500702393863`*^-10", "0.15189311279643478`", "12125", 
            "7.445500702393863`*^-10", "1.5676875191569581`", "40987"},
          {"3", "0.05195545788059537`", "0.3350390835422475`", "6633", 
            "0.05195545788059537`", "1.5676875191569581`", "28862"},
          {"4", "0.25911922418919126`", "0.5129354711726744`", "4081", 
            "0.25911922418919126`", "1.5676875191569581`", "22229"},
          {"5", "0.44970057631459015`", "0.6628668871649726`", "2793", 
            "0.44970057631459015`", "1.5676875191569581`", "18148"},
          {"6", "0.6069543154347786`", "0.7823291902482497`", "2058", 
            "0.6069543154347786`", "1.5676875191569581`", "15355"},
          {"7", "0.7318794806095382`", "0.8775324942174965`", "1609", 
            "0.7318794806095382`", "1.5676875191569581`", "13297"},
          {"8", "0.8307837565401166`", "0.9531965550862663`", "1234", 
            "0.8307837565401166`", "1.5676875191569581`", "11688"},
          {"9", "0.9100192049787418`", "1.0144297738185908`", "972", 
            "0.9100192049787418`", "1.5676875191569581`", "10454"},
          {"10", "0.974477306566102`", "1.0653952741558337`", "828", 
            "0.974477306566102`", "1.5676875191569581`", "9482"},
          {"11", "1.0277701854941421`", "1.1079235466755983`", "741", 
            "1.0277701854941421`", "1.5676875191569581`", "8654"},
          {"12", "1.0724751850594085`", "1.1439874986606635`", "588", 
            "1.0724751850594085`", "1.5676875191569581`", "7913"},
          {"13", "1.1104591882508383`", "1.1747102815088895`", "484", 
            "1.1104591882508383`", "1.5676875191569581`", "7325"},
          {"14", "1.1431044019623227`", "1.2013997882281353`", "459", 
            "1.1431044019623227`", "1.5676875191569581`", "6841"},
          {"15", "1.1714537408791352`", "1.2245134521145953`", "404", 
            "1.1714537408791352`", "1.5676875191569581`", "6382"},
          {"16", "1.1963058059303653`", "1.2453206624208102`", "361", 
            "1.1963058059303653`", "1.5676875191569581`", "5978"},
          {"17", "1.2182802426992625`", "1.2635030795331976`", "308", 
            "1.2182802426992625`", "1.5676875191569581`", "5617"},
          {"18", "1.2377801955304335`", "1.279825487177051`", "282", 
            "1.2377801955304335`", "1.5676875191569581`", "5309"},
          {"19", "1.2552652827883237`", "1.2946287297769528`", "254", 
            "1.2552652827883237`", "1.5676875191569581`", "5027"},
          {"20", "1.2710067939978171`", "1.3080363534747985`", "215", 
            "1.2710067939978171`", "1.5676875191569581`", "4773"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableHeadings -> {None, {"N", 
        "min \[CapitalDelta]\[CapitalTheta] (=)", 
        "max \[CapitalDelta]\[CapitalTheta] (=)", "samples (=)", 
        "min \[CapitalDelta]\[CapitalTheta] (>=)", 
        "max \[CapitalDelta]\[CapitalTheta] (>=)", 
        "samples (>=)"}}]&)]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 827}},
WindowSize->{916, 731},
WindowMargins->{{8, Automatic}, {19, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 39, 0, 105, "Title"],
Cell[1781, 53, 234, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[2040, 61, 31, 0, 53, "Section"],
Cell[2074, 63, 328, 7, 71, "Text"],
Cell[2405, 72, 321, 8, 70, "Input"],
Cell[2729, 82, 102, 3, 33, "Text"],
Cell[2834, 87, 68, 1, 30, "Input"],
Cell[2905, 90, 189, 3, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3131, 98, 29, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[3185, 102, 26, 0, 47, "Subsection"],
Cell[3214, 104, 300, 5, 52, "Text"],
Cell[3517, 111, 1250, 20, 150, "Input"],
Cell[4770, 133, 120, 3, 33, "Text"],
Cell[4893, 138, 136, 2, 30, "Input"],
Cell[5032, 142, 68, 0, 33, "Text"],
Cell[5103, 144, 68, 1, 30, "Input"],
Cell[5174, 147, 110, 2, 30, "Input"],
Cell[5287, 151, 126, 3, 33, "Text"],
Cell[5416, 156, 247, 5, 30, "Input"],
Cell[5666, 163, 248, 5, 30, "Input"],
Cell[5917, 170, 125, 3, 33, "Text"],
Cell[6045, 175, 490, 10, 110, "Input"],
Cell[6538, 187, 304, 5, 50, "Input"],
Cell[6845, 194, 444, 7, 71, "Text"],
Cell[7292, 203, 1418, 27, 230, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8747, 235, 29, 0, 31, "Subsection"],
Cell[8779, 237, 107, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[8911, 244, 80, 1, 30, "Input"],
Cell[8994, 247, 2947, 47, 331, "Output"]
}, Open  ]],
Cell[11956, 297, 110, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[12091, 304, 88, 1, 30, "Input"],
Cell[12182, 307, 2890, 47, 331, "Output"]
}, Open  ]],
Cell[15087, 357, 112, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[15224, 364, 90, 1, 30, "Input"],
Cell[15317, 367, 2951, 47, 335, "Output"]
}, Open  ]],
Cell[18283, 417, 113, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[18421, 424, 91, 1, 30, "Input"],
Cell[18515, 427, 2977, 47, 331, "Output"]
}, Open  ]],
Cell[21507, 477, 210, 4, 52, "Text"],
Cell[21720, 483, 184, 3, 30, "Input"],
Cell[21907, 488, 185, 3, 30, "Input"],
Cell[22095, 493, 185, 3, 30, "Input"],
Cell[22283, 498, 185, 3, 30, "Input"],
Cell[22471, 503, 191, 3, 30, "Input"],
Cell[22665, 508, 192, 3, 30, "Input"],
Cell[22860, 513, 192, 3, 30, "Input"],
Cell[23055, 518, 192, 3, 30, "Input"],
Cell[23250, 523, 184, 3, 30, "Input"],
Cell[23437, 528, 191, 3, 30, "Input"],
Cell[23631, 533, 185, 3, 30, "Input"],
Cell[23819, 538, 192, 3, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24060, 547, 37, 0, 33, "Section"],
Cell[24100, 549, 287, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[24412, 558, 359, 5, 70, "Input"],
Cell[24774, 565, 3505, 56, 347, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

